@@ -1,11 +1,11 @@
 import os
+import math
 
 import torch
 from torch import Tensor
 from torch.nn import Module
 
 from ..modules import Linear, LayerNorm, Embedding, TransformerEncoder, TransformerDecoder, TanhHead
-from ..utils import transposed_cat
 
 
 class BartModel(Module):
@@ -56,7 +56,7 @@ class BartModel(Module):
         encoder_outputs = self.encoder(x, attention_mask)
         encoder_outputs = self.pre_decoder_layer(encoder_outputs)
         encoder_outputs = encoder_outputs.view(
-            encoder_outputs.shape[:2] + (self.decoder_layers, 2, self.encoder_heads, -1)).transpose(1, 4).contiguous()
+            encoder_outputs.shape[:2] + (self.decoder_layers, 2, self.encoder_heads, -1)).transpose(1, 4)
 
         x = self.embeddings(decoder_input_ids) + self.decoder_positions.weight[:input_ids.shape[1]]
         x = self.decoder_norm(x)
@@ -92,12 +92,15 @@ class BartForSequenceClassification(Module):
             'ffn.lin2': 'fc2'
         }
 
+        scale = math.sqrt(self.transformer.encoder.layers[0].attention.dim_per_head)
+
         for layer_ind in range(len(self.transformer.encoder.layers)):
             prefix = f'model.encoder.layers.{layer_ind}.'
             for w in ('weight', 'bias'):
-                state_dict[f'{prefix}attention.pre_attention.{w}'] = transposed_cat([
+                state_dict[f'{prefix}self_attn.q_proj.{w}'] /= scale
+                state_dict[f'{prefix}attention.pre_attention.{w}'] = torch.cat([
                     state_dict.pop(f'{prefix}self_attn.{k}_proj.{w}') for k in ('q', 'k', 'v')
-                ])
+                ], dim=0)
                 for new_name, old_name in encoder_old_names.items():
                     state_dict[f'{prefix}{new_name}.{w}'] = state_dict.pop(f'{prefix}{old_name}.{w}')
 
@@ -113,12 +116,16 @@ class BartForSequenceClassification(Module):
             'norm3': 'final_layer_norm'
         }
 
-        for layer_ind in range(len(self.transformer.encoder.layers)):
+        scale = math.sqrt(self.transformer.decoder.layers[0].self_attention.dim_per_head)
+
+        for layer_ind in range(len(self.transformer.decoder.layers)):
             prefix = f'model.decoder.layers.{layer_ind}.'
             for w in ('weight', 'bias'):
-                state_dict[f'{prefix}self_attention.pre_attention.{w}'] = transposed_cat([
+                state_dict[f'{prefix}self_attn.q_proj.{w}'] /= scale
+                state_dict[f'{prefix}encoder_attn.q_proj.{w}'] /= scale
+                state_dict[f'{prefix}self_attention.pre_attention.{w}'] = torch.cat([
                     state_dict.pop(f'{prefix}self_attn.{k}_proj.{w}') for k in ('q', 'k', 'v')
-                ])
+                ], dim=0)
                 for new_name, old_name in decoder_old_names.items():
                     state_dict[f'{prefix}{new_name}.{w}'] = state_dict.pop(f'{prefix}{old_name}.{w}')
 
