@@ -1,12 +1,12 @@
 import os
 import logging
+import math
 
 import torch
-from torch.nn import Module, LayerNorm, Linear
+from torch.nn import Module
 from torch.nn.functional import gelu
 
-from ..modules import TransformerEncoder, Embeddings
-from ..utils import transposed_cat
+from ..modules import LayerNorm, Linear, TransformerEncoder, Embeddings
 
 
 logger = logging.getLogger(__name__)
@@ -66,12 +66,16 @@ class DistilBertForMaskedLM(Module):
             for name, old_name in module_names.items():
                 new_key = new_key.replace(f'{old_name}.', f'{name}.')
             state_dict[new_key] = state_dict.pop(key)
+
+        scale = math.sqrt(self.transformer.encoder.layers[0].attention.dim_per_head)
+
         for layer_ind in range(len(self.transformer.encoder.layers)):
             prefix = f'transformer.encoder.layers.{layer_ind}.'
             for p in ('weight', 'bias'):
-                state_dict[f'{prefix}attention.pre_attention.{p}'] = transposed_cat([
+                state_dict[f'{prefix}attention.q_lin.{p}'] /= scale
+                state_dict[f'{prefix}attention.pre_attention.{p}'] = torch.cat([
                     state_dict.pop(f'{prefix}attention.{k}_lin.{p}') for k in ('q', 'k', 'v')
-                ])
+                ], dim=0)
                 state_dict[f'{prefix}norm1.{p}'] = state_dict.pop(f'{prefix}sa_layer_norm.{p}')
                 state_dict[f'{prefix}norm2.{p}'] = state_dict.pop(f'{prefix}output_layer_norm.{p}')
         return super().load_state_dict(state_dict, strict)
@@ -82,6 +86,6 @@ class DistilBertForMaskedLM(Module):
         prediction_logits = gelu(prediction_logits)
         prediction_logits = self.vocab_layer_norm(prediction_logits)
         prediction_logits = self.vocab_projector(prediction_logits)
-        mask_indices = torch.nonzero(input_ids == self.mask_token_id, as_tuple=True)[1]
+        mask_indices = torch.nonzero(input_ids == self.mask_token_id)[:, 1]
         mask_indices = mask_indices.unsqueeze(-1).unsqueeze(-1).expand(-1, -1, prediction_logits.shape[-1])
         return prediction_logits.gather(dim=1, index=mask_indices)[:, 0].softmax(dim=-1).gather(dim=-1, index=targets)
