@@ -15,9 +15,6 @@ class MultiHeadAttention(Module):
         self.n_heads = n_heads
         self.dim_per_head = dim // n_heads
 
-    def transpose_for_scores(self, x: torch.Tensor) -> torch.Tensor:
-        return x.view(x.shape[:2] + (3, self.n_heads, self.dim_per_head)).transpose(1, 3)
-
     def forward(
             self,
             hidden_states,
@@ -34,8 +31,6 @@ class MultiHeadAttention(Module):
         if incr_state is not None:
             k_v = torch.cat([incr_state, k_v], dim=1)
 
-        incr_state = k_v.view(batch_size, self.n_heads, 2, -1, self.dim_per_head) if get_incr_state else None
-
         dot_prod = torch.matmul(query, k_v[:, :, 0].transpose(2, 3))
 
         dot_prod += mask
@@ -47,7 +42,7 @@ class MultiHeadAttention(Module):
 
         context_layer = self.out_lin(context_layer)
 
-        return context_layer, incr_state
+        return context_layer, k_v if get_incr_state else None
 
 
 class DecoderEncoderAttention(Module):
