@@ -1,8 +1,10 @@
 import torch
-from torch.nn import Module, ModuleList, LayerNorm
+from torch.nn import Module, ModuleList
 
+from .base_modules import LayerNorm
 from .attention import MultiHeadAttention
-from .modules import TransformerFFN
+from .feed_forward import TransformerFFN
+from ..utils import neg_inf
 
 
 class TransformerEncoderLayer(Module):
@@ -43,9 +45,9 @@ class TransformerEncoder(Module):
         self.n_heads = n_heads
 
     def forward(self, tensor: torch.Tensor, mask: torch.Tensor) -> torch.Tensor:
-        attn_mask = ~mask.repeat_interleave(repeats=self.n_heads, dim=0).unsqueeze(1).expand(-1, mask.shape[1], -1)
+        attn_mask = ((~mask).type_as(tensor) * neg_inf(tensor.dtype == torch.bool)).unsqueeze(1).unsqueeze(1).expand(
+            -1, self.n_heads, mask.shape[1], -1)
 
         for layer in self.layers:
             tensor = layer.forward(tensor, attn_mask)
-
-        return tensor * mask.unsqueeze(-1)
+        return tensor
